pub enum ParseError {
ValueOutOfValidRange,
Unsupported,
InvalidHeader,
InvalidArgumentHeader,
InvalidTimestamp,
InvalidArgument,
InvalidRecordType,
Incomplete(usize),
}Expand description
Errors which occur when interacting with streams of diagnostic records.
Variants
ValueOutOfValidRange
We attempted to parse bytes as a type for which the bytes are not a valid pattern.
Unsupported
We attempted to parse or encode values which are not yet supported by this implementation of the Fuchsia Tracing format.
InvalidHeader
We failed to parse a record header.
InvalidArgumentHeader
We failed to parse a record header.
InvalidTimestamp
We failed to parse a record timestamp.
InvalidArgument
We failed to parse a record argument.
InvalidRecordType
The record type wasn’t the one we expected: LOGS
Incomplete(usize)
We failed to parse a complete item.